********************
Welcome to Sloth CI!
********************

.. image:: https://img.shields.io/pypi/v/sloth-ci.svg?style=flat-square
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/sloth-ci.svg?style=flat-square
    :alt: Downloads

.. image:: https://img.shields.io/pypi/l/sloth-ci.svg?style=flat-square
    :alt: License


.. image:: sloth.png


**Sloth CI** builds docs, runs tests, and deploys to servers when you push to GitHub or Bitbucket.

The goal is to give you the easiest way to automatize things, with no memory overhead or overcomplicated setup. Installing, configuring, and running Sloth CI takes about two minutes, then you control it remotely via protected `web API <http://sloth-ci.com/api.html>`__ or `command line interface <http://sloth-ci.com/cli.html>`__.

-   `Quickstart → <http://sloth-ci.com/quickstart.html>`__
-   `Cookbook → <http://sloth-ci.com/cookbook/index.html>`__
-   `Developer Guide → <http://sloth-ci.com/dev/index.html>`__


Contribute
==========

`Report a bug <https://bitbucket.org/sloth-ci/sloth-ci/issues/new>`__

`Fork and improve <https://bitbucket.org/sloth-ci/sloth-ci/fork>`__